@@ -1,9 +1,10 @@
 <?php
-/**
+/*
  *  This file is part of NOALYSS under GPL
  * 
  */
 /**
+ * @file
  * @brief this file is used for the ajax from the extension, it will the ajax.php file from the plugin directory
  * all the variable are in $_REQUEST
  * The code (of the plugin) is required
@@ -13,16 +14,16 @@
  */
 if ( ! defined ('ALLOWED') ) define ('ALLOWED',1);
 require_once '../include/constant.php';
-require_once NOALYSS_INCLUDE.'/class_database.php';
-require_once NOALYSS_INCLUDE.'/class_user.php';
-require_once NOALYSS_INCLUDE.'/class_extension.php';
+require_once NOALYSS_INCLUDE.'/lib/class_database.php';
+require_once NOALYSS_INCLUDE.'/class/class_user.php';
+require_once NOALYSS_INCLUDE.'/class/class_extension.php';
 if ( !isset ($_REQUEST['gDossier'])) exit();
 
-require_once NOALYSS_INCLUDE.'/class_own.php';
+require_once NOALYSS_INCLUDE.'/class/class_own.php';
 mb_internal_encoding("UTF-8");
 
 global $g_user,$cn,$g_parameter;
-$cn=new Database(dossier::id());
+$cn=Dossier::connect();
 $g_parameter=new Own($cn);
 $g_user=new User($cn);
 $g_user->check(true);
