@@ -768,7 +768,9 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $acc_operation=new Acc_Operation($this->db);
             $acc_operation->date=$e_date;
             $acc_operation->echeance=$e_ech;
-            $acc_operation->amount=abs(round($tot_debit,2));
+            // Total DEB
+            $acc_operation->amount=$this->db->get_value("select sum(j_montant) from jrnx where j_grpt = $1 and j_debit='t'",
+                    array($seq));
             $acc_operation->desc=$e_comm;
             $acc_operation->grpt=$seq;
             $acc_operation->jrn=$p_jrn;
@@ -1139,15 +1141,15 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         // Record the current number of article
 
         $e_comment=(isset($e_comment))?$e_comment:"";
-		$p_article= ( isset ($nb_item))?$nb_item:$this->get_min_row();
-        $max=($p_article < $this->get_min_row())?$this->get_min_row():$p_article;
+	$p_article= ( isset ($nb_item))?$nb_item:$this->get_min_row();
+        $p_article=($p_article < $this->get_min_row())?$this->get_min_row():$p_article;
 
         $Hid=new IHidden();
 		$r.=$Hid->input("nb_item",$p_article);
 
         // For each article
         //--
-        for ($i=0;$i< $max ;$i++)
+        for ($i=0;$i< $p_article ;$i++)
         {
             // Code id, price & vat code
             //--
@@ -1338,6 +1340,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         }
         $date_limit=$lPeriode->get_date_limit();
         $r="";
+        $r .= '<div id="summary_op1">';
         $r.='<TABLE>';
         if ( $p_summary ) {
             $jr_id=$this->db->get_value('select jr_id from jrn where jr_internal=$1',array($this->internal));
@@ -1375,6 +1378,10 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $r.='<tr>';
         $r.='<td> ' . _('Période Comptable') . '</td><td> ' .hb( $date_limit['p_start'] . '-' . $date_limit['p_end']) . '</td>';
         $r.='</tr>';
+        $r.='</table>';
+        $r.='</div>';
+        $r .= '<div id="summary_op2">';
+        $r.='<table>';
         $r.='<tr>';
         $r.='<td> ' . _('Journal') . '</td><td> ' . hb($this->get_name()) . '</td>';
         $r.='</tr>';
@@ -1387,6 +1394,9 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $r.='<td> ' . _('Fournisseur') . '</td><td> ' . hb($e_client . ':' . $client_name) . '</td>';
         $r.='</tr>';
         $r.='</table>';
+        $r.='</div>';
+        $r.='<div style="position:float;clear:both">';
+        $r.='</div>';
         $r.='<h2>' . _('Détail articles achetés') . '</h2>';
         $r.='<p class="decale">';
         $r.='<table class="result" >';
