@@ -632,7 +632,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         }
         $date_limit = $lPeriode->get_date_limit();
         $r = "";
-        
+        $r .= '<div id="summary_op1" >';
         $r.='<TABLE>';
         if ( $p_summary ) {
             $jr_id=$this->db->get_value('select jr_id from jrn where jr_internal=$1',array($this->internal));
@@ -669,6 +669,10 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $r.='<tr>';
         $r.='<td> ' . _('Période Comptable') . '</td><td> ' .hb( $date_limit['p_start'] . '-' . $date_limit['p_end']) . '</td>';
         $r.='</tr>';
+        $r.='</table>';
+        $r.='</div>';
+        $r .= '<div id="summary_op2">';
+        $r.='<table>';
         $r.='<tr>';
         $r.='<td> ' . _('Journal') . '</td><td> ' . hb($this->get_name()) . '</td>';
         $r.='</tr>';
@@ -680,6 +684,10 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $r.='<td> ' . _('Client') . '</td><td> ' . hb($e_client . ':' . $client_name) . '</td>';
         $r.='</tr>';
         $r.='</table>';
+        $r.='</div>';
+        $r.='<div style="position:float;clear:both">';
+        $r.='</div>';
+        
         $r.='<h2>' . _('Détail articles vendus') . '</h2>';
         $r.='<p class="decale">';
         $r.='<table class="result" >';
@@ -1028,7 +1036,6 @@ EOF;
         else
             $op_date = (!isset($e_date) ) ? '' : $e_date;
 
-
         $e_ech = (isset($e_ech)) ? $e_ech : "";
         $e_comm = (isset($e_comm)) ? $e_comm : "";
 
@@ -1163,14 +1170,14 @@ EOF;
         $Hid = new IHidden();
         $p_article = ( isset($nb_item)) ? $nb_item : $this->get_min_row();
         $r.=$Hid->input("nb_item", $p_article);
-        $max = ($p_article < $this->get_min_row()) ? $this->get_min_row() : $p_article;
+        $p_article = ($p_article < $this->get_min_row()) ? $this->get_min_row() : $p_article;
 
 
         $f_legend_detail = _("Détail articles vendus");
 
         // For each article
         //--
-        for ($i = 0; $i < $max; $i++) {
+        for ($i = 0; $i < $p_article; $i++) {
             // Code id, price & vat code
             //--
             $march = (isset(${"e_march$i"})) ? ${"e_march$i"} : "";
