@@ -63,7 +63,7 @@ class Anc_Operation
     /*!\brief constructor
      *
      */
-    function Anc_Operation ($p_cn,$p_id=0)
+    function __construct ($p_cn,$p_id=0)
     {
         $this->db=$p_cn;
         $this->id=$p_id;
@@ -800,6 +800,7 @@ class Anc_Operation
     function save_update_form($p_array)
     {
         extract($p_array);
+        if ( ! isset($opanc)) return;
         for ($i = 0; $i < count($opanc); $i++)
         {
             /* clean operation_analytique */
