@@ -43,7 +43,7 @@ class Document
     /* Constructor
      * \param $p_cn Database connection
      */
-    function Document($p_cn,$p_d_id=0)
+    function __construct($p_cn,$p_d_id=0)
     {
         $this->db=$p_cn;
         $this->d_id=$p_d_id;
@@ -156,15 +156,14 @@ class Document
 
             $file_to_parse=$filename;
         }
-		if ( $p_filename !="") {
-
+	if ( $p_filename !="") {
 			$this->d_filename=$this->compute_filename($p_filename, $this->d_filename);
-		}
+	}
         $this->SaveGenerated($dirname.DIRECTORY_SEPARATOR.$file_to_parse);
         // Invoice
         $href=http_build_query(array('gDossier'=>Dossier::id(),"d_id"=>$this->d_id,'act'=>'RAW:document'));
-        $ret='<A class="mtitle" HREF="export.php?'.$href.'">Document g&eacute;n&eacute;r&eacute;</A>';
-        @rmdir($dirname);
+        $ret='<A class="mtitle" HREF="export.php?'.$href.'">'._('Document').'</A>';
+        
         return $ret;
     }
 
@@ -193,7 +192,7 @@ class Document
         $h=fopen($infile_name,"r");
 
         // check if tmpdir exist otherwise create it
-        $temp_dir=$_SERVER["DOCUMENT_ROOT"].DIRECTORY_SEPARATOR.'tmp';
+        $temp_dir=$_ENV['TMP'];
         if ( is_dir($temp_dir) == false )
         {
             if ( mkdir($temp_dir) == false )
@@ -547,6 +546,7 @@ class Document
      *  - [ACOMPTE]
      *  - [TITLE]
      *  - [DESCRIPTION]
+     *  - [COMM_PAYMENT]
      *
      * \param $p_tag TAG
      * \param $p_array data from $_POST
@@ -1173,13 +1173,17 @@ class Document
         case 'TITLE':
             $title=HtmlInput::default_value_request("ag_title", "");
             return $title;
-
-		}
+        case 'COMM_PAYMENT':
+            if ( isset($p_array["e_comm_paiement"])) {
+            return $p_array["e_comm_paiement"];
+             } else return "";
+	}
         /*
          * retrieve the value of ATTR for e_march
          */
         if (preg_match('/^ATTR/', $p_tag) == 1)
         {
+            $r="";
             // Retrieve f_id
             if ( isset ($p_array['e_march'.$this->counter]))
             {
@@ -1192,12 +1196,14 @@ class Document
          */
         if (preg_match('/^BENEFATTR/', $p_tag) == 1)
         {
+            $r="";
             $qcode=isset($p_array['qcode_benef'])?$p_array['qcode_benef']:'';
             // Retrieve f_id
              $r=$this->replace_special_tag($qcode,$p_tag);
         }
         if (preg_match('/^CUSTATTR/', $p_tag) == 1)
         {
+            $r="";
             if ( isset($p_array['qcode_dest']) || isset($p_array['e_client']) )
             {
                 $qcode=(isset($p_array['qcode_dest']))?$p_array['qcode_dest']:$p_array['e_client'];
