@@ -243,10 +243,7 @@ echo $op->form_get('do.php?'.$url);
 echo '</div>';
 echo '</div>';
 
-if ( is_msie() == 0 ) 
-    echo '<div style="position:absolute"  class="content">';
-else
-    echo '<div class="content">';
+echo '<div class="content">';
 
 echo '<p class="notice">'.$p_msg.'</p>';
 try
@@ -254,7 +251,7 @@ try
     $payment=HtmlInput::default_value_request("e_mp", 0);
     echo "<FORM class=\"print\"NAME=\"form_detail\" METHOD=\"POST\" >";
     /* request for a predefined operation */
-    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']))
+    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']) && ! isset($correct) )
     {
         // used a predefined operation
         //
@@ -296,7 +293,7 @@ catch (Exception $e)
     alert($e->getMessage());
     return;
 }
-if (!isset($_POST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
+if (!isset($_REQUEST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
 	echo create_script(" get_last_date()");
 echo create_script(" update_name()");
 echo '</div>';
