@@ -172,7 +172,7 @@ show_tab(a_tab,'facturation_div_id');
             }
 
             /* Show button  */
-            echo '<h1 style="float:right;margin-right:20%"> Enregistrement </h1>';
+            echo '<h1> Enregistrement </h1>';
 
             echo $Ledger->confirm($_POST,true);
             /* Show link for Invoice */
@@ -230,10 +230,7 @@ show_tab(a_tab,'facturation_div_id');
 //
 // pre defined operation
 //
-if ( is_msie() == 0 ) 
-    echo '<div style="position:absolute"  class="content">';
-else
-    echo '<div class="content">';
+echo '<div class="content">';
 
 if (!isset($_REQUEST ['p_jrn']))
 {
@@ -269,7 +266,7 @@ try
 
     echo "<FORM class=\"print\" NAME=\"form_detail\" METHOD=\"POST\" >";
     /* request for a predefined operation */
-    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']))
+    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']) && ! isset($correct))
     {
         // used a predefined operation
         //
@@ -334,7 +331,7 @@ echo '<div class="content">';
     {
 		echo '<script> update_pj()</script>';
     }
-	if (!isset($_POST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
+	if (!isset($_REQUEST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
 	{
 		echo create_script(" get_last_date()");
 	}
