@@ -43,6 +43,14 @@ if ( !defined("NOALYSS_HOME")) define ("NOALYSS_HOME",dirname($dirname)."/html")
 if ( !defined("NOALYSS_PLUGIN")) define ("NOALYSS_PLUGIN",$g_ext_dir);
 if ( !defined("NOALYSS_INCLUDE")) define ("NOALYSS_INCLUDE",$g_include_dir);
 if ( !defined("NOALYSS_TEMPLATE")) define ("NOALYSS_TEMPLATE",$g_template_dir);
+// pdftk can deal with all the PDF , for some of them it is preferable to fix it
+// with convert , see also PDF2PS and PS2PDF if yes
+if ( !defined("FIX_BROKEN_PDF")) define ("FIX_BROKEN_PDF",'NO');
+
+// version < 6.9.1.4 , the default administrator was phpcompta
+if ( !defined('NOALYSS_ADMINISTRATOR')) {
+    define ('NOALYSS_ADMINISTRATOR','phpcompta');
+}
 
 require_once NOALYSS_INCLUDE.'/constant.security.php';
 
@@ -76,7 +84,7 @@ define ('SMALLX','&#x2D5D;');
 define ('BUTTONADD',"&#10010;");
 
 
-define ('SVNINFO',6913);
+define ('SVNINFO',6915);
 if ( ! defined  ('DEBUG')) {
     define ("DEBUG",false);
 }
@@ -96,7 +104,7 @@ if ( !defined("SITE_UPDATE_PLUGIN"))
 if ( ! defined ("SYSINFO_DISPLAY")) {
     define ("SYSINFO_DISPLAY",TRUE);
 }
-define ("DBVERSION",123);
+define ("DBVERSION",125);
 define ("MONO_DATABASE",25);
 define ("DBVERSIONREPO",16);
 define ('NOTFOUND','--not found--');
@@ -233,7 +241,26 @@ if (file_exists($convert_gif_pdf))
     define ('CONVERT_GIF_PDF','NOT');
     
 }
+/**
+ * PDF2PS is used when the PDF is broken , used with FIX_BROKEN_PDF
+ */
+$pdf2ps='/usr/bin/pdf2ps';
 
+if ( ! file_exists($pdf2ps) ) 
+    define ('PDF2PS','NOT');
+ else
+    define ('PDF2PS',$pdf2ps);
+/**
+ * PS2PDF is used when the PDF is broken , used with FIX_BROKEN_PDF
+ */
+$ps2pdf='/usr/bin/ps2pdf';
+
+if ( ! file_exists($ps2pdf) ) 
+    define ('PS2PDF','NOT');
+ else
+    define ('PS2PDF',$ps2pdf);
+
+ 
 /**
  * Outil pour manipuler les PDF 
  */
@@ -247,6 +274,10 @@ else
     define ('PDFTK','NOT');  
 }
 
+// If it is not a mono folder it is a multi one
+if ( !defined('MULTI')) {
+    define('MULTI',1);
+}
 
 define ('JS_INFOBULLE','
         <DIV id="bulle" class="infobulle"></DIV>
