@@ -60,29 +60,29 @@ $align=array('L','C','C','L','R','R','R','R');
 
 $Libelle=sprintf("(%s) %s [ %s ]",$Fiche->id,$Fiche->getName(),$Fiche->get_quick_code());
 $pdf->SetFont('DejaVu','',10);
-$pdf->Cell(0,8,$Libelle,1,0,'C');
-$pdf->Ln();
+$pdf->write_cell(0,8,$Libelle,1,0,'C');
+$pdf->line_new();
 
 
 $pdf->SetFont('DejaVuCond','',8);
 $l=0;
-$pdf->Cell($size[$l],6,'Date',0,0,'L');
+$pdf->write_cell($size[$l],6,'Date',0,0,'L');
 $l++;
-$pdf->Cell($size[$l],6,'Ref',0,0,'C');
+$pdf->write_cell($size[$l],6,'Ref',0,0,'C');
 $l++;
-$pdf->Cell($size[$l],6,'Journal',0,0,'C');
+$pdf->write_cell($size[$l],6,'Journal',0,0,'C');
 $l++;
-$pdf->Cell($size[$l],6,'Libellé',0,0,'L');
+$pdf->write_cell($size[$l],6,'Libellé',0,0,'L');
 $l++;
-$pdf->Cell($size[$l],6,'Let',0,0,'R');
+$pdf->write_cell($size[$l],6,'Let',0,0,'R');
 $l++;
-$pdf->Cell($size[$l],6,'Debit',0,0,'R');
+$pdf->write_cell($size[$l],6,'Debit',0,0,'R');
 $l++;
-$pdf->Cell($size[$l],6,'Credit',0,0,'R');
+$pdf->write_cell($size[$l],6,'Credit',0,0,'R');
 $l++;
-$pdf->Cell($size[$l],6,'Prog',0,0,'R');
+$pdf->write_cell($size[$l],6,'Prog',0,0,'R');
 $l++;
-$pdf->ln();
+$pdf->line_new();
 $tot_deb=0;
 $tot_cred=0;
 $progress=0;
@@ -113,12 +113,12 @@ for ($e=0;$e<count($array);$e++)
 
             $pdf->SetFont('DejaVu','B',8);
             $pdf->LongLine(15,6,_('totaux'),0,'L');
-            $pdf->Cell(15,6,$current_exercice,0,0,'L');
+            $pdf->write_cell(15,6,$current_exercice,0,0,'L');
             $pdf->LongLine(40,6,$solde,0,'L');
-            $pdf->Cell(40,6,$str_debit,0,0,'R');
-            $pdf->Cell(40,6,$str_credit,0,0,'R');
-            $pdf->Cell(40,6,$str_diff_solde,0,0,'R');
-            $pdf->Ln();
+            $pdf->write_cell(40,6,$str_debit,0,0,'R');
+            $pdf->write_cell(40,6,$str_credit,0,0,'R');
+            $pdf->write_cell(40,6,$str_diff_solde,0,0,'R');
+            $pdf->line_new();
             /*
             * reset total and current_exercice
             */
@@ -132,15 +132,15 @@ for ($e=0;$e<count($array);$e++)
     $progress=bcadd($progress,$delta);
 
     $date=shrink_date($row['j_date_fmt']);
-    $pdf->LongLine($size[$l],6,$date,0,$align[$l]);
+    $pdf->write_cell($size[$l],6,$date,0,0,$align[$l]);
     $l++;
     if ( $row['jr_pj_number'] == '')
-      $pdf->Cell($size[$l],6,"",0,0,$align[$l]);
+      $pdf->write_cell($size[$l],6,"",0,0,$align[$l]);
     else
-      $pdf->Cell($size[$l],6,$row['jr_pj_number'],0,0,$align[$l]);
+      $pdf->write_cell($size[$l],6,$row['jr_pj_number'],0,0,$align[$l]);
 
     $l++;
-    $pdf->LongLine($size[$l],6,mb_substr($row['jrn_def_code'],0,14),0,$align[$l]);
+    $pdf->write_cell($size[$l],6,mb_substr($row['jrn_def_code'],0,14),0,0,$align[$l]);
     $l++;
     $pdf->LongLine($size[$l],6,($row['description'].'('.$row['jr_internal'].")"),0,$align[$l]);
 
@@ -153,7 +153,7 @@ for ($e=0;$e<count($array);$e++)
     $l++;
     $pdf->LongLine($size[$l],6,(sprintf('% 12.2f',abs($progress))),0,$align[$l]);
     $l++;
-    $pdf->ln();
+    $pdf->line_new();
     $tot_deb=bcadd($tot_deb,$row['deb_montant']);
     $tot_cred=bcadd($tot_cred,$row['cred_montant']);
     /* -------------------------------------- */
@@ -167,11 +167,11 @@ for ($e=0;$e<count($array);$e++)
         for ($f=0;$f<count($a_detail);$f++)
         {
             $l=0;
-            $pdf->Cell($size[$l],6,'',0,0,$align[$l]);
+            $pdf->write_cell($size[$l],6,'',0,0,$align[$l]);
             $l++;
-            $pdf->Cell($size[$l],6,$a_detail[$f]['j_qcode'],0,0,'L');
+            $pdf->write_cell($size[$l],6,$a_detail[$f]['j_qcode'],0,0,'L');
             $l++;
-            $pdf->Cell($size[$l],6,$a_detail[$f]['j_poste'],0,0,'R');
+            $pdf->write_cell($size[$l],6,$a_detail[$f]['j_poste'],0,0,'R');
             $l++;
             if ( $a_detail[$f]['j_qcode']=='')
                 $lib=$a_detail[$f]['pcm_lib'];
@@ -181,19 +181,19 @@ for ($e=0;$e<count($array);$e++)
                 $lib=$cn->get_value('select ad_value from fiche_detail where ad_id=$1 and f_id=$2',
                                     array(ATTR_DEF_NAME,$f_id));
             }
-            $pdf->Cell($size[$l],6,$lib,0,0,$align[$l]);
+            $pdf->write_cell($size[$l],6,$lib,0,0,$align[$l]);
             $l++;
-            $pdf->Cell($size[$l],6,(($a_detail[$f]['letter']!=-1)?$a_detail[$f]['letter']:''),0,0,$align[$l]);
+            $pdf->write_cell($size[$l],6,(($a_detail[$f]['letter']!=-1)?$a_detail[$f]['letter']:''),0,0,$align[$l]);
             $l++;
 
             $deb=($a_detail[$f]['debit']=='D')?$a_detail[$f]['j_montant']:'';
             $cred=($a_detail[$f]['debit']=='C')?$a_detail[$f]['j_montant']:'';
 
-            $pdf->Cell($size[$l],6,(sprintf('% 12.2f',$deb)),0,0,$align[$l]);
+            $pdf->write_cell($size[$l],6,(sprintf('% 12.2f',$deb)),0,0,$align[$l]);
             $l++;
-            $pdf->Cell($size[$l],6,(sprintf('% 12.2f',$cred)),0,0,$align[$l]);
+            $pdf->write_cell($size[$l],6,(sprintf('% 12.2f',$cred)),0,0,$align[$l]);
             $l++;
-            $pdf->ln();
+            $pdf->line_new();
         }
     }
 
@@ -214,15 +214,15 @@ $str_diff_solde=sprintf("%12.2f €",$diff_solde);
 
 $pdf->SetFont('DejaVu','B',8);
 
-$pdf->Cell(160,5,'Débit',0,0,'R');
-$pdf->Cell(30,5,$str_debit,0,0,'R');
-$pdf->Ln();
-$pdf->Cell(160,5,'Crédit',0,0,'R');
-$pdf->Cell(30,5,$str_credit,0,0,'R');
-$pdf->Ln();
-$pdf->Cell(160,5,'Solde '.$solde,0,0,'R');
-$pdf->Cell(30,5,$str_diff_solde,0,0,'R');
-$pdf->Ln();
+$pdf->write_cell(160,5,'Débit',0,0,'R');
+$pdf->write_cell(30,5,$str_debit,0,0,'R');
+$pdf->line_new();
+$pdf->write_cell(160,5,'Crédit',0,0,'R');
+$pdf->write_cell(30,5,$str_credit,0,0,'R');
+$pdf->line_new();
+$pdf->write_cell(160,5,'Solde '.$solde,0,0,'R');
+$pdf->write_cell(30,5,$str_diff_solde,0,0,'R');
+$pdf->line_new();
 
 $fDate=date('dmy-Hi');
 $pdf->Output('fiche-'.$fDate.'.pdf','D');
